@@ -19,18 +19,16 @@
 #include "spellcheck.h"
 
 #include <QClipboard>
-
-#include <KApplication>
-// #include <KDebug>
-#include <KGlobal>
-#include <KIcon>
+#include <QDebug>
+#include <QLocale>
 #include <QSet>
 
+#include <KLocalizedString>
+
 SpellCheckRunner::SpellCheckRunner(QObject* parent, const QVariantList &args)
     : Plasma::AbstractRunner(parent, args)
 {
     Q_UNUSED(args)
-    KGlobal::locale()->insertCatalog(QLatin1String( "krunner_spellcheckrunner" ));
     setObjectName(QLatin1String( "Spell Checker" ));
     setIgnoredTypes(Plasma::RunnerContext::FileSystem | Plasma::RunnerContext::NetworkLocation);
     setSpeed(AbstractRunner::SlowSpeed);
@@ -58,7 +56,6 @@ void SpellCheckRunner::loaddata()
     }
     //store all language names, makes it possible to type "spell german TERM" if english locale is set
     //Need to construct a map between natual language names and names the spell-check recognises.
-    KLocale *locale = KGlobal::locale();
     const QStringList avail = m_spellers[""]->availableLanguages();
     //We need to filter the available languages so that we associate the natural language
     //name (eg. 'german') with one sub-code.
@@ -89,7 +86,8 @@ void SpellCheckRunner::loaddata()
             code = family.first();
         }
         //Finally, add code to the map.
-        const QString name = locale->languageCodeToName(fcode);
+        // FIXME: We need someway to map languageCodeToName
+        const QString name;// = locale->languageCodeToName(fcode);
         if (!name.isEmpty()) {
             m_languages[name.toLower()] = code;
         }
@@ -217,28 +215,31 @@ void SpellCheckRunner::match(Plasma::RunnerContext &context)
         QStringList suggestions;
         const bool correct = speller->checkAndSuggest(query,suggestions);
         if (correct) {
-            match.setIcon(KIcon(QLatin1String( "checkbox" )));
+            match.setIcon(QIcon::fromTheme(QLatin1String( "checkbox" )));
             match.setText(i18n("Correct")+QLatin1String(": ")+query);
         } else {
-            match.setIcon(KIcon(QLatin1String( "edit-delete" )));
+            match.setIcon(QIcon::fromTheme(QLatin1String( "edit-delete" )));
             const QString recommended = i18n("Suggested words: %1", suggestions.join(i18nc("seperator for a list of words", ", ")));
             //TODO: try setting a text and a subtext, with the subtext being the suggestions
             match.setText(recommended);
             match.setData(suggestions);
         }
     } else {
-        match.setIcon(KIcon(QLatin1String("task-attention")));
+        match.setIcon(QIcon::fromTheme(QLatin1String("task-attention")));
         match.setText(i18n("Could not find a dictionary."));
     }
 
-    context.addMatch(term, match);
+    context.addMatch(match);
 }
 
 void SpellCheckRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
 {
     Q_UNUSED(context)
     //Copy words to clipboard
-    kapp->clipboard()->setText(match.data().toString());
+    // FIXME:
+    // kapp->clipboard()->setText(match.data().toString());
 }
 
+K_EXPORT_PLASMA_RUNNER(krunner_spellcheck, SpellCheckRunner)
+
 #include "spellcheck.moc"
